<?php

declare(strict_types=1);

namespace App\Tests;

use PHPUnit\Framework\TestCase;
use PHPUnit\Framework\Attributes\CoversClass;
use Symfony\Component\Console\Application;
use Symfony\Component\Console\Tester\CommandTester;
use App\CommandShow;

#[CoversClass(CommandShow::class)]
final class CommandShowTest extends \PHPUnit\Framework\TestCase
{
    public function testInvalidConfig(): void
    {

        $applicationd = new Application('backup', "1.1.1");

        $applicationd->add(new CommandShow());


        $command = $applicationd->find('show');
        $commandTester = new CommandTester($command);
        $commandTester->execute(['config' => "bad_file"]);

        $output = $commandTester->getDisplay();
        $this->assertStringContainsString('[ERROR] Configuration error: File "bad_file" does not exist.', $output);
    }

    public function testGoodConfig(): void
    {
        exec('rclone test makefiles temp/source 2>&1');

        $applicationd = new Application('backup', "1.1.1");

        $applicationd->add(new CommandShow());


        $command = $applicationd->find('show');
        $commandTester = new CommandTester($command);
        $commandTester->execute(['config' => "config.example.yml"]);

        $output = $commandTester->getDisplay();
        $this->assertStringContainsString('Example', $output);
        $this->assertStringContainsString('temp/source', $output);
        $this->assertStringContainsString('temp/destination', $output);
    }
}
